@@ -1,7 +1,7 @@
 package Getopt::Long::Subcommand;
 
 our $DATE = '2017-08-01'; # DATE
-our $VERSION = '0.100'; # VERSION
+our $VERSION = '0.101'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,9 +10,11 @@ use Log::ger;
 
 require Exporter;
 our @ISA = qw(Exporter);
+## no critic (Modules::ProhibitAutomaticExportation)
 our @EXPORT = qw(
                     GetOptions
             );
+## use critic
 
 # XXX completion & configure are actually only allowed at the top-level
 my @known_cmdspec_keys = qw(
@@ -231,9 +233,9 @@ sub GetOptions {
             bundling => do {
                 if (!$cmdspec{configure}) {
                     1;
-                } elsif (grep { 'bundling' } @{ $cmdspec{configure} }) {
+                } elsif (grep { $_ eq 'bundling' } @{ $cmdspec{configure} }) {
                     1;
-                } elsif (grep { 'no_bundling' } @{ $cmdspec{configure} }) {
+                } elsif (grep { $_ eq 'no_bundling' } @{ $cmdspec{configure} }) {
                     0;
                 } else {
                     0;
@@ -292,7 +294,7 @@ Getopt::Long::Subcommand - Process command-line options, with subcommands and co
 
 =head1 VERSION
 
-This document describes version 0.100 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2017-08-01.
+This document describes version 0.101 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2017-08-01.
 
 =head1 SYNOPSIS
 
